@@ -29,6 +29,6 @@ def run(project, wrapper, args, output=None, one_container=True):
             with open(output, 'w') as fp:
                 to_json(result, fp)
         else:
-            print to_json(result)
+            print(to_json(result))
     finally:
         r.chown()
