@@ -38,17 +38,18 @@ class SimpleParallelWrapper(Wrapper):
         self.outputs._save_meta()
 
         # Serialize outputs to job result
-        result = self.outputs.__json__()
-        for key, val in result.items():
-            result[key] = val.__json__()
-        return result
+        return self.outputs.__json__()
 
     @require(100, require.CPU_NEGLIGIBLE)
     def merge(self, job_results):
         for result in job_results:
             for output_id, files in result.iteritems():
-                for file_path in files:
-                    getattr(self.outputs, output_id).add_file(file_path)._load_meta()
+                out = getattr(self.outputs, output_id)
+                if isinstance(files, basestring):
+                    setattr(self.outputs, output_id, files)
+                else:
+                    for file_path in files:
+                        out.add_file(file_path)._load_meta()
 
 
 S = '__!__'
